@@ -22,6 +22,8 @@ class HDFSWrapper(object):
     def __init__(self):
         self.__m_HDFS_Handler__ = None
         self.__m_HDFS_WebFSDir__ = None
+        self.__m_HDFS_User__ = None
+        self.__m_HDFS_WebFSURL__ = None
 
     def HDFS_makedirs(self, hdfs_path):
         """ 创建目录 """
@@ -44,6 +46,8 @@ class HDFSWrapper(object):
         m_HDFS_Protocal = p_szURL.split("://")[0]
         m_HDFS_NodePort = p_szURL[len(m_HDFS_Protocal) + 3:].split("/")[0]
         m_HDFS_WebFSURL = m_HDFS_Protocal + "://" + m_HDFS_NodePort
+        self.__m_HDFS_User__ = p_szUser
+        self.__m_HDFS_WebFSURL__ = m_HDFS_WebFSURL
         self.__m_HDFS_WebFSDir__ = p_szURL[len(m_HDFS_WebFSURL):]
         self.__m_HDFS_Handler__ = InsecureClient(url=m_HDFS_WebFSURL,
                                                  user=p_szUser,
@@ -51,6 +55,14 @@ class HDFSWrapper(object):
         # 尝试创建目录，如果目录不存在的话
         self.__m_HDFS_Handler__.makedirs(self.__m_HDFS_WebFSDir__.replace('\\', '/'))
 
+    def HDFS_CD(self, p_szPath):
+        self.__m_HDFS_WebFSDir__ = os.path.join(self.__m_HDFS_WebFSDir__, p_szPath)
+        self.__m_HDFS_Handler__ = InsecureClient(url=self.__m_HDFS_WebFSURL__,
+                                                 user=self.__m_HDFS_User__,
+                                                 root=self.__m_HDFS_WebFSDir__)
+        # 尝试创建目录，如果目录不存在的话
+        self.__m_HDFS_Handler__.makedirs(self.__m_HDFS_WebFSDir__.replace('\\', '/'))
+
     def HDFS_status(self, hdfs_path=""):
         """ 返回目录下的文件 """
         if self.__m_HDFS_Handler__ is None:
@@ -115,6 +127,14 @@ class HDFSWrapper(object):
                     m_hdfs_filepath = os.path.dirname(hdfs_path)
                     m_hdfs_filename = os.path.basename(hdfs_path)
             try:
+                remote_status = self.__m_HDFS_Handler__.status(
+                    hdfs_path=
+                    os.path.join(self.__m_HDFS_WebFSDir__, m_hdfs_filepath).replace('\\', '/'),
+                    strict=True)
+                if remote_status['type'] == "FILE":
+                    # 远程以为是目录的地方其实放了一个奇怪的文件，于是删掉它
+                    self.__m_HDFS_Handler__.delete(
+                        os.path.join(self.__m_HDFS_WebFSDir__, m_hdfs_filepath).replace('\\', '/'), recursive=True)
                 remote_status = self.__m_HDFS_Handler__.status(
                     os.path.join(self.__m_HDFS_WebFSDir__, m_hdfs_filepath, m_hdfs_filename).replace('\\', '/'))
                 if remote_status['type'] == "DIRECTORY":
@@ -142,6 +162,13 @@ class HDFSWrapper(object):
                 self.HDFS_Connect(m_HDFSServer, m_HDFSUser)
                 return None, None, None, None, "Hdfs Server set successful."
 
+            matchObj = re.match(r"hdfs\s+cd\s+(.*)$",
+                                m_szSQL, re.IGNORECASE | re.DOTALL)
+            if matchObj:
+                m_HDFSPath = str(matchObj.group(1)).strip()
+                self.HDFS_CD(m_HDFSPath)
+                return None, None, None, None, "Hdfs root dir change successful."
+
             matchObj = re.match(r"hdfs\s+status\s+(.*)$",
                                 m_szSQL, re.IGNORECASE | re.DOTALL)
             if matchObj:
@@ -149,7 +176,6 @@ class HDFSWrapper(object):
                 m_ReturnFileList = self.HDFS_status(m_TargetFileList)
                 m_Result = []
                 for (m_FileName, m_FileProperties) in m_ReturnFileList:
-                    m_PermissionMask = ""
                     if m_FileProperties["type"] == "FILE":
                         m_PermissionMask = "-"
                     elif m_FileProperties["type"] == "DIRECTORY":
@@ -191,11 +217,17 @@ class HDFSWrapper(object):
                                 m_szSQL, re.IGNORECASE | re.DOTALL)
             if matchObj:
                 if matchObj:
+                    m_Bak_WebFSDir = self.__m_HDFS_WebFSDir__
                     m_FileDeleted = str(matchObj.group(1)).strip()
-                    m_FileList = self.HDFS_list(recusive=False)
+                    m_FileDeletedPath = os.path.dirname(m_FileDeleted)
+                    m_FileDeletedName = os.path.basename(m_FileDeleted)
+                    self.HDFS_CD(m_FileDeletedPath)
+                    m_FileList = self.HDFS_list(self.__m_HDFS_WebFSDir__, recusive=False)
                     for row in m_FileList:
-                        if fnmatch.fnmatch(row[0], m_FileDeleted):
+                        if fnmatch.fnmatch(os.path.basename(row[0]), m_FileDeletedName):
                             self.__m_HDFS_Handler__.delete(row[0], recursive=True)
+                    # 重新返回原目录
+                    self.HDFS_CD(m_Bak_WebFSDir)
                 return None, None, None, None, "Hdfs file deleted successful."
 
             matchObj = re.match(r"hdfs\s+makedirs\s+(.*)$",
@@ -258,7 +290,6 @@ class HDFSWrapper(object):
                 m_ReturnFileList = self.HDFS_list(m_TargetFileList, recusive=True)
                 m_Result = []
                 for (m_FileName, m_FileProperties) in m_ReturnFileList:
-                    m_PermissionMask = ""
                     if m_FileProperties["type"] == "FILE":
                         m_PermissionMask = "-"
                     elif m_FileProperties["type"] == "DIRECTORY":
